/*!
 * @file pushbutton.c
 *
 * @date Feb 7, 2017
 * @author Ting
 */

#include "pushbutton.h"
#include "atrasos.h"

/**
* @brief Inicializa botoeiras 
*/
void initPushbuttonIRQA (void) {
    /*!  Habilita os clocks do mdulo PORTA */
    SIM_SCGC5 |= (xxx) ;    

    /*! Configura pino A5 como GPIO (MUX = 001) */
    PORTA_PCR5 |= PORT_PCR_MUX(xxx);

    /*! Configura pino A12 como GPIO (MUX = 001) */
    PORTA_PCR12 |= PORT_PCR_MUX(xxx);

    /*! Configura a direcao dos pinos 5 e 12 da PORTA como entrada */
    GPIOA_PDDR &= ~(GPIO_PDDR_PDD(GPIO_PIN(5)) |
    			    GPIO_PDDR_PDD(GPIO_PIN(12)));

}

/**
* @brief L&ecirc; o valor do pino 12 da porta A
 * @param [in] pta 0 (PTA5) ou 1 (PTA12)
* @return estado do bot&atilde;o (0 apertado; 1 normal)
*/
short le_pta (enum _tipo_pta pta) {
  volatile unsigned int a;
  short tmp;
        
  a = xxxx;       /*! Faz a leitura na PORTA (32 bits) */
  switch (pta) {
     case PTA5: tmp = (short) (a & GPIO_PIN(5)); /*! Extrair o bit 5 */
     	 break;
     case PTA12: tmp = (short) (a & GPIO_PIN(12)); /*! Extrair o bit 12 */
  }
  return tmp;
}

/**
 * @brief Intervalo de tempo de aperto
 * @param [in] pta 0 (PTA5) ou 1 (PTA12)
 * @return m&uacute;ltiplos de 50000*10us (fa&ccedil;a ajustes finos conforme a sua velocidade de aperto) 
 * 
 */
uint8_t tempo_espera (enum _tipo_pta pta) {
        short estado;
        uint8_t i;
        uint8_t indice=0;
        for (i=0; i < 5; i++) {
            delay10us(25000);   /*! tempo estimado para o usu&aacute;rio soltar o bot&atilde;o */
            estado = le_pta(pta);

            if (estado) return indice;
        	indice++;
        }
        
        while (!le_pta(pta)) ;  /*! atingiu o m&aacute;ximo tempo permitido:
        							aguarda soltar a botoeira */
        
        return indice; 
}
